@@ -1,24 +1,18 @@
-
- /* ==================================================================
-
-    FILE: "/home/joze/src/tclreadline/wishrl.c"
-    LAST MODIFICATION: "Sat, 25 Mar 2000 20:52:13 +0100 (joze)"
-    (C) 1998 - 2000 by Johannes Zellner, <johannes@zellner.org>
-    $Id: wishrl.c,v 1.3 2000/03/25 20:59:12 joze Exp $
-    ---
-
-    tclreadline -- gnu readline for tcl
-    http://www.zellner.org/tclreadline/
-    Copyright (c) 1998 - 2000, Johannes Zellner <johannes@zellner.org>
-
-    This software is copyright under the BSD license.
-
-    ================================================================== */  
+ /* ================================================================== *
+  * FILE: wishrl.c
+  * $Id: 4913e9e764b572a0b6658ab4a3a696c68b33cb56 $
+  * ---
+  * tclreadline -- gnu readline for tcl
+  * http://www.zellner.org/tclreadline/
+  * Copyright (c) 1998 - 2014, Johannes Zellner <johannes@zellner.org>
+  * This software is copyright under the BSD license.
+  * ================================================================== */
 
 #ifdef HAVE_CONFIG_H
-#   include "config.h"
+#  include "config.h"
 #endif
 
+#include <stdlib.h>
 #include <tcl.h>
 #include <tk.h>
 #include <tclreadline.h>
@@ -33,16 +27,16 @@ TclreadlineAppInit(Tcl_Interp* interp)
     int status;
 
     if (TCL_ERROR == Tcl_Init(interp)) {
-	return TCL_ERROR;
+        return TCL_ERROR;
     }
     if (TCL_ERROR == Tk_Init(interp)) {
-	return TCL_ERROR;
+        return TCL_ERROR;
     }
     if (TCL_ERROR == Tclreadline_Init(interp)) {
-	return TCL_ERROR;
+        return TCL_ERROR;
     }
     Tcl_StaticPackage(interp, "tclreadline",
-	Tclreadline_Init, Tclreadline_SafeInit);
+    Tclreadline_Init, Tclreadline_SafeInit);
 #if (TCL_MAJOR_VERSION == 7) && (TCL_MINOR_VERSION == 4)
     tcl_RcFileName = "~/.wishrc";
 #else
@@ -50,8 +44,8 @@ TclreadlineAppInit(Tcl_Interp* interp)
 #endif
     sprintf(file, "%s/tclreadlineInit.tcl", TCLRL_LIBRARY);
     if ((status = Tcl_EvalFile(interp, file))) {
-	fprintf(stderr, "(TclreadlineAppInit) unable to eval %s\n", file);
-	exit (1);
+        fprintf(stderr, "(TclreadlineAppInit) unable to eval %s\n", file);
+        exit (EXIT_FAILURE);
     }
     return TCL_OK;
 }
@@ -60,5 +54,5 @@ int
 main(int argc, char *argv[])
 {
     Tk_Main(argc, argv, TclreadlineAppInit);
-    return 0;
+    return EXIT_SUCCESS;
 }
